==> XLConnect_0.1-8.tar.gz: XLConnect/R/workbook.renameSheet.R <==
#############################################################################
#
# XLConnect
# Copyright (C) 2010-2012 Mirai Solutions GmbH
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#############################################################################

#############################################################################
#
# Renaming worksheets from a workbook
# 
# Author: Martin Studer, Mirai Solutions GmbH
#
#############################################################################
 
setGeneric("renameSheet",
	function(object, sheet, ...) standardGeneric("renameSheet"))

setMethod("renameSheet", 
		signature(object = "workbook", sheet = "numeric"), 
		function(object, sheet, newName) {
			xlcCall(object, "renameSheet", as.integer(sheet - 1), newName)
			invisible()
		}
)

setMethod("renameSheet", 
		signature(object = "workbook", sheet = "character"), 
		function(object, sheet, newName) {
			xlcCall(object, "renameSheet", sheet,  newName)
			invisible()
		}
)

==> XLConnect_0.2-2.tar.gz: XLConnect/R/workbook.renameSheet.R <==
#############################################################################
#
# XLConnect
# Copyright (C) 2010-2012 Mirai Solutions GmbH
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#############################################################################

#############################################################################
#
# Renaming worksheets from a workbook
# 
# Author: Martin Studer, Mirai Solutions GmbH
#
#############################################################################
 
setGeneric("renameSheet",
	function(object, sheet, newName) standardGeneric("renameSheet"))

setMethod("renameSheet", 
		signature(object = "workbook", sheet = "numeric"), 
		function(object, sheet, newName) {
			xlcCall(object, "renameSheet", as.integer(sheet - 1), newName)
			invisible()
		}
)

setMethod("renameSheet", 
		signature(object = "workbook", sheet = "character"), 
		function(object, sheet, newName) {
			xlcCall(object, "renameSheet", sheet,  newName)
			invisible()
		}
)
